@@ -30,7 +30,12 @@ from typing import Optional, Callable, Tuple, Any
 
 from moose_lib.dmv2 import get_streams, DeadLetterModel
 from moose_lib import cli_log, CliLogData, DeadLetterQueue
-from moose_lib.commons import EnhancedJSONEncoder, moose_management_port
+from moose_lib.commons import (
+    EnhancedJSONEncoder,
+    moose_management_port,
+    get_kafka_consumer,
+    get_kafka_producer,
+)
 
 # Force stdout to be unbuffered
 sys.stdout = io.TextIOWrapper(
@@ -243,7 +248,7 @@ sasl_config = {
 # When migrating - make sure the ACLs are updated to use the new prefix. 
 # And make sure the prefixes are the same in the ts-moose-lib and py-moose-lib
 streaming_function_id = f'flow-{source_topic.name}-{target_topic.name}' if target_topic else f'flow-{source_topic.name}'
-log_prefix = f"{source_topic.name} -> {target_topic.name}" if target_topic else f"{source_topic.name} -> None"
+log_prefix = f"{source_topic.name} -> {target_topic.name}" if target_topic else f"{source_topic.name} (consumer)"
 
 
 def log(msg: str) -> None:
@@ -294,29 +299,18 @@ def create_consumer() -> KafkaConsumer:
     Returns:
         Configured KafkaConsumer instance
     """
-    if sasl_config['mechanism'] is not None:
-        return KafkaConsumer(
-            source_topic.name,
-            client_id="python_streaming_function_consumer",
-            group_id=streaming_function_id,
-            bootstrap_servers=broker,
-            sasl_plain_username=sasl_config['username'],
-            sasl_plain_password=sasl_config['password'],
-            sasl_mechanism=sasl_config['mechanism'],
-            security_protocol=args.security_protocol,
-            # consumer_timeout_ms=10000,
-            value_deserializer=lambda m: json.loads(m.decode('utf-8'))
-        )
-    else:
-        log("No sasl mechanism specified. Using default consumer.")
-        return KafkaConsumer(
-            source_topic.name,
-            client_id="python_streaming_function_consumer",
-            group_id=streaming_function_id,
-            bootstrap_servers=broker,
-            # consumer_timeout_ms=10000,
-            value_deserializer=lambda m: json.loads(m.decode('utf-8'))
-        )
+    kwargs = dict(
+        broker=broker,
+        client_id="python_streaming_function_consumer",
+        group_id=streaming_function_id,
+        value_deserializer=lambda m: json.loads(m.decode("utf-8")),
+        sasl_username=sasl_config.get("username"),
+        sasl_password=sasl_config.get("password"),
+        sasl_mechanism=sasl_config.get("mechanism"),
+        security_protocol=args.security_protocol,
+    )
+    consumer = get_kafka_consumer(**kwargs)
+    return consumer
 
 
 def create_producer() -> Optional[KafkaProducer]:
@@ -330,20 +324,13 @@ def create_producer() -> Optional[KafkaProducer]:
     """
     max_request_size = KafkaProducer.DEFAULT_CONFIG['max_request_size'] if target_topic is None \
         else target_topic.max_message_bytes
-    if sasl_config['mechanism'] is not None:
-        return KafkaProducer(
-            bootstrap_servers=broker,
-            sasl_plain_username=sasl_config['username'],
-            sasl_plain_password=sasl_config['password'],
-            sasl_mechanism=sasl_config['mechanism'],
-            security_protocol=args.security_protocol,
-            max_request_size=max_request_size
-        )
-    log("No sasl mechanism specified. Using default producer.")
-    return KafkaProducer(
-        bootstrap_servers=broker,
-        max_in_flight_requests_per_connection=1,
-        max_request_size=max_request_size
+    return get_kafka_producer(
+        broker=broker,
+        sasl_username=sasl_config.get("username"),
+        sasl_password=sasl_config.get("password"),
+        sasl_mechanism=sasl_config.get("mechanism"),
+        security_protocol=args.security_protocol,
+        max_request_size=max_request_size,
     )
 
 
@@ -416,7 +403,6 @@ def main():
             kafka_refs['consumer'] = consumer
             kafka_refs['producer'] = producer
 
-            # Subscribe to topic
             consumer.subscribe([source_topic.name])
 
             log("Kafka consumer and producer initialized in processing thread")
